package demo.screen.IMAGE;

import org.objectweb.telosys.common.TelosysException;
import org.objectweb.telosys.dal.dao.DatabaseSession;
import org.objectweb.telosys.rpl.ScreenRequest;
import org.objectweb.telosys.rpl.ScreenRequestParameters;
import org.objectweb.telosys.rpl.ScreenResponse;
import org.objectweb.telosys.screen.core.ScreenContext;
import org.objectweb.telosys.screen.core.ScreenData;
import org.objectweb.telosys.screen.core.StandardScreenDataAccessor;
import org.objectweb.telosys.screen.env.ScreenSession;
import org.objectweb.telosys.upload.FileUploaded;

import demo.dao.ImageDAO;
import demo.vo.ImageVO;


/**
 * @author Telosys Team
 * 
 */
public class IMAGEmgr extends StandardScreenDataAccessor
{
    private final static String IMAGE_FILE = "imagefile";
    
    private ImageDAO _daoImage = new ImageDAO();

    /**
     * Constructor
     */
    public IMAGEmgr()
    {
        super(IMAGEdata.class);
    }

    //---------------------------------------------------------------------------
    private void setPrimaryKey(ImageVO image, ScreenRequest request) throws TelosysException
    {        
        image.setName( request.getParameter("name") );
    }

    //---------------------------------------------------------------------------
    private void load(ScreenData screenData, ImageVO image, DatabaseSession dbSession) throws TelosysException
    {
        System.out.println("load");
        IMAGEdata data = (IMAGEdata) screenData;
        //--- Load master table
        int iRet = _daoImage.load(image, dbSession);
        if (iRet > 0)
        {
            //--- Consider DATA as "found"
            data.setFound(); 
        	//--- Populate the Screen Data ...
            data.setImage(image);
        }
        else
        {
            data.setNotFound(); // Consider as "not found"
        }
    }
    
    //---------------------------------------------------------------------------
    // ScreenContext life cycle
    //---------------------------------------------------------------------------
    public void onCreate(ScreenContext screenContext, ScreenRequestParameters params, ScreenSession screenSession, DatabaseSession dbSession) throws TelosysException
    {
        System.out.println("onCreate : dbSession = " + dbSession );
    }
    public void onReuse(ScreenContext screenContext, ScreenRequestParameters params, ScreenSession screenSession, DatabaseSession dbSession) throws TelosysException
    {
        System.out.println("onReuse : dbSession = " + dbSession);
        // Clear the image file attribute 
        screenContext.removeAttribute(IMAGE_FILE);
    }

    //---------------------------------------------------------------------------
    public void load(ScreenData screenData, ScreenContext screenContext, ScreenRequest request, ScreenResponse response, DatabaseSession dbSession) throws TelosysException
    {
        System.out.println("load : dbSession = " + dbSession  );
        IMAGEdata data = (IMAGEdata) screenData;
        
        //--- Load the bean from the DataBase
		ImageVO image = new ImageVO();
		setPrimaryKey(image, request );
		load( screenData, image, dbSession);  
        System.out.println("Data found ? : " + screenData.isFound() );
		
		//--- Store the image file as a ScreenContext attribute for access via <t:image >
		byte[] content = image.getImg();
		String type = null ; // "Content-Type" ( Mime Type )
		FileUploaded fileInMemory = new FileUploaded(null, content, type, 0L, null, null);
		screenContext.setAttribute(IMAGE_FILE, fileInMemory);		
    }
    
    //---------------------------------------------------------------------------
    public void save(ScreenData screenData, ScreenContext screenContext, ScreenRequest request, ScreenResponse response, DatabaseSession dbSession) throws TelosysException
    {
        IMAGEdata data = (IMAGEdata) screenData;
        ImageVO image = data.getImage();
        if ( image != null )
        {
	        //--- Try to get the image file from the ScreenContext attribute ( upload target )
	        Object o = screenContext.getAttribute(IMAGE_FILE);
	        if ( o != null )
	        {
	            if ( o instanceof FileUploaded )
	            {
	                FileUploaded fileInMemory = (FileUploaded) o ;
	                
	                image.setImg( fileInMemory.getData() ) ;
	            }
	        }

	        //--- Save the bean in the DataBase
	        _daoImage.save(image, dbSession);
        }
    }

    //---------------------------------------------------------------------------
    public void delete(ScreenData screenData, ScreenContext screenContext, ScreenRequest request, ScreenResponse response, DatabaseSession dbSession) throws TelosysException
    {
        //--- DELETE the given primary key ( from request parameters )
		ImageVO image = new ImageVO();
		setPrimaryKey(image, request );
        _daoImage.delete(image, dbSession);
        screenContext.removeAttribute(IMAGE_FILE);
    }
    
    //---------------------------------------------------------------------------
    public void insert(ScreenData screenData, ScreenContext screenContext, ScreenRequest request, ScreenResponse response, DatabaseSession dbSession) throws TelosysException
    {
        // TODO Auto-generated method stub
    }

    //---------------------------------------------------------------------------
    public void update(ScreenData screenData, ScreenContext screenContext, ScreenRequest request, ScreenResponse response, DatabaseSession dbSession) throws TelosysException
    {
        // TODO Auto-generated method stub
    }

}